@@ -22,7 +22,7 @@ with MAD(current_dir, log = True) as mad:
     mad.ps.beam = mad.psbeam
     mad.survey("srv", sequence = mad.ps)
 
-    mad.callMethod(None, "srv", "write", "'data/PS_survey_py.tfs'", ['name', 'kind', 's', 'l', 'angle', 'x', 'y', 'z', 'theta'])
+    mad.callMethod(None, "srv", "write", "'PS_survey_py.tfs'", ['name', 'kind', 's', 'l', 'angle', 'x', 'y', 'z', 'theta'])
 
     mad.twiss("tws", sequence = mad.ps, method = 6, nslice = 3, chrom = True)
 
@@ -32,6 +32,6 @@ with MAD(current_dir, log = True) as mad:
                         'k0sl', 'k1sl', 'k2sl', 'k3sl', 'k4sl', 'k5sl', 'k6sl',
                         'ksl', 'hkick', 'vkick'])
     
-    mad.callMethod(None, mad.tws, "write", "'data/PS_twiss_py.tfs'", ['name','kind','s',
+    mad.callMethod(None, mad.tws, "write", "'PS_twiss_py.tfs'", ['name','kind','s',
                                                         'x','px','beta11','alfa11','beta22','alfa22','dx','dpx','mu1','mu2',
                                                         'l','angle','k0l','k1l','k2l','k3l','hkick','vkick'])
\ No newline at end of file
